import { Component, OnInit } from '@angular/core';
import { Socket } from './services/socket/socket.service';
import { Settings } from './services/settings/settings.service';
import { Account } from './services/account/account.service';
import { Project } from './services/project/project.service';
import { Router } from '@angular/router';

declare global {
  interface Window {
    heyLlama: any;
  }
}

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent implements OnInit {
  public show: boolean = false;
  public disable: boolean = true;
  public connection: boolean = true;
  public loading: boolean = true;
  public error: string = '';
  constructor(private router: Router, public settings: Settings, private socket: Socket, private account: Account, private project: Project) { }
  ngOnInit() {
    this.onRoute();
    this.checkStatus();
    this.router.events.subscribe(this.onRoute);
    this.account.onSet.subscribe(status => {
      if (status == true) {
        this.settings.load()
          .then(() => {
            this.show = true;
            this.disable = true;
            this.makeEasterEgg();
            this.setEvent();
          });
      } else if (status == false) {
        this.removeEvent();
        this.show = false;
      }
    });
    this.project.onSelect.subscribe(status => {
      this.disable = !status;
    });
    this.checkAuth();
  }

  onRoute() {
    this.show = window.location.pathname.includes('/auth/') ? false : true;
    if (this.show == false) this.disable = false;
    else if (this.show == true && this.project && this.project.id && this.project.id != null) this.disable = false;
    else this.disable = true;
  }

  makeEasterEgg() {
    window.heyLlama = () => {
      let llama = document.getElementById('llama');
      llama.style.display = 'block';
      setTimeout(() => {
        llama.removeAttribute('style');
      }, 10000);
      return "It's me, llama as easter egg!"
    }
  }

  checkAuth(auth = true) {
    return new Promise(resolve => {
      let token = window.localStorage.getItem('token') || window.sessionStorage.getItem('token') || null;
      // Need to login
      if (token == null) {
        console.log("[RayConnect Log]: Need to login");
        this.show = false;
        this.loading = false;
        this.disable = false;
        this.socket.rayconnect.GetGuestAccess();
        if (window.location.pathname.includes('auth') == false) this.router.navigate(['/auth/login']);
        resolve();
      } else {
        // this.account.set();
        // this.loading = false;
        // return;
        (async () => {
          if (auth == true) {
            console.log("[RayConnect Log]: Authenticating ...");
            await this.socket.rayconnect.Auth(token)
            console.log("[RayConnect Log]: Authenticated");
          } else {
            return Promise.resolve();
          }
        })()
          .then(() => {
            return this.socket.rayconnect.Request({
              scope: 'chat',
              uniqueID: 'chat-admin',
              TokenID: '*',
              address: 'chat/me',
              info: { method: 'CHAT', data: {} }
            },
              {
                scope: 'chat',
                address: 'chat/me/data',
                method: 'CHAT'
              })
          })
          .then(data => {
            if (window.location.pathname.includes('auth')) this.router.navigate(['/panel/dashboard']);
            this.account.set();
            this.getProject();
            data = data['data'] || { fullname: null, email: null, balance: 0 };

            this.account.fullname = data['fullname'] || 'کاربر ناشناس';
            this.account.email = data['email'] || 'X@Y.Z';
            this.account.avatar = data['avatar'] || 0;
            this.account.phone = data['phone'];
            this.account.balance = data['balance'] || 0;
            resolve();
          }).catch(error => {
            if (error == 'request timeout.' || error == 'request timeout : 3000') {
              this.error = 'در حال دریافت اطلاعات حساب شما'
              setTimeout(() => {
                this.checkAuth(false);
              }, 1000);
            }
          })
      }
    })
  }

  getProject() {
    let id = window.localStorage.getItem('project') || window.sessionStorage.getItem('project') || null;
    if (id == null) {
      this.disable = true;
      this.loading = false;
    } else {
      this.socket.rayconnect.Request({
        scope: 'project',
        uniqueID: 'chat-admin',
        TokenID: '*',
        address: 'project/get',
        info: {
          method: 'GET',
          data: { id }
        }
      },
        {
          scope: 'project',
          address: 'project/data',
          method: 'SEND'
        }).then(data => {
          this.loading = false;
          this.project.set(data['data'], this.settings.forgetProject);
        }).catch(error => {
          if (error == 'request timeout.' || error == 'request timeout : 3000') {
            this.error = 'در حال دریافت پروژه های شما'
            setTimeout(() => {
              this.getProject();
            }, 1000);
          }
        })
    }
  }

  checkStatus() {
    this.socket.rayconnect
      .OnConnect(() => {
        console.log(`[RayConnect status]: Connect at ${new Date()}`);
        this.connection = true;
        setTimeout(() => {
          this.connection = null;
        }, 3000);
      });

    this.socket.rayconnect
      .DisOnConnect(() => {
        console.log(`[RayConnect status]: Disconnect at ${new Date()}`);

        this.connection = false;
      });
  }

  removeEvent() {
    document.removeEventListener("keyup", () => { });
    document.removeEventListener("keydown", () => { });
  }

  setEvent() {
    let keys = [];
    document.addEventListener('keydown', event => {
      keys.push(event.key)
    });

    document.addEventListener('keyup', event => {
      if (JSON.stringify(keys) == JSON.stringify(["Alt", "n"])) this.toggle('nightMode');

      keys.splice(keys.indexOf(event.key), 1);
    })
  }

  toggle(what: string) {
    this.settings[what] = !this.settings[what];
    this.settings.setChanges(what);
    this.settings.saveChanges();
  }
}
