import { Component, OnInit } from '@angular/core';
import { Settings } from '../../services/settings/settings.service';
import { Project } from '../../services/project/project.service';
import { Socket } from '../../services/socket/socket.service';

@Component({
  selector: 'app-select-project',
  templateUrl: './select-project.component.html',
  styleUrls: ['./select-project.component.css']
})
export class SelectProjectComponent implements OnInit {

  public projects = [];
  public step: number = 0;
  public data = { name: '', icon: -1, color: 1, descriptions: '', domain: [''] };
  public error = { name: false, domain: false };
  public icons = [];
  public loading: boolean = true;
  public exists: boolean = false;
  constructor(public settings: Settings, private project: Project, private socket: Socket) { }

  ngOnInit() {
    this.getProjects();
    this.icons = this.project.database.icons;
  }

  getProjects() {
    this.loading = true;
    this.socket.rayconnect.Request({
      scope: 'project',
      uniqueID: 'chat-admin',
      TokenID: '*',
      address: 'project/list',
      info: {
        method: 'GET',
        data: {}
      }
    },
      {
        scope: 'project',
        address: 'project/list',
        method: 'SEND'
      }).then(data => {
        this.loading = false;
        this.projects = data['data'];
      })
  }

  checkDomain() {
    this.loading = true;
    this.exists = false;
    this.socket.rayconnect.Request({
      scope: 'project',
      uniqueID: 'chat-admin',
      TokenID: '*',
      address: 'project/domain/check',
      info: {
        method: 'DO',
        data: {
          domain: this.data.domain[0]
        }
      }
    },
      {
        scope: 'project',
        address: 'project/domain/checked',
        method: 'SEND'
      }).then(data => {
        this.loading = false;
        let result = data['data']['check'];
        if (result == false) this.step += 1;
        else {
          this.exists = true;
          this.error.domain = true;
        }
      })
  }

  next() {
    if (this.step == 1) {
      if (this.data.name.length == 0) this.error.name = true;
      else this.step += 1;
    } else if (this.step == 2) {
      if (this.data.domain[0].length == 0 || /^[a-zA-Z0-9][a-zA-Z0-9-]{1,61}[a-zA-Z0-9](?:\.[a-zA-Z]{2,})+$/.test(this.data.domain[0]) == false) this.error.domain = true;
      else this.checkDomain();
    } else if (this.step == 3) {
      if (this.data.icon != -1) this.step += 1;
    } else if (this.step == 4) {
      this.step += 1;
    } else if (this.step == 5) {
      this.loading = true;
      this.socket.rayconnect.Request({
        scope: 'project',
        uniqueID: 'chat-admin',
        TokenID: '*',
        address: 'project/add',
        info: {
          method: 'DO',
          data: this.data
        }
      },
        {
          scope: 'project',
          address: 'project/added',
          method: 'SEND'
        }).then(data => {
          this.loading = false;
          if (data['data']['status'] == false && data['data']['message'] == "THIS_DOMAIN_WAS_DEFINED") this.step = 2;
          else if (data['data']['status'] == true) this.project.set(data['data']['created'], this.settings.forgetProject);
          else;
        })
    }
  }

  toggle() {
    let what = 'forgetProject';
    this.settings[what] = !this.settings[what];
    this.settings.setChanges(what);
    this.settings.saveChanges();
  }
}
