import { Component, OnInit } from '@angular/core';
import paths, { Item as Path } from '../../database/path.database';
import { Functions } from '../../services/functions/functions.service';
import { Settings } from '../../services/settings/settings.service';
import { Account } from '../../services/account/account.service';
import { Project } from '../../services/project/project.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-bar',
  templateUrl: './app-bar.component.html',
  styleUrls: ['./app-bar.component.css']
})
export class AppBarComponent implements OnInit {

  public mini: boolean = false;
  public mode: string = '';
  public pathname: string = window.location.pathname;
  public path: Path;
  public paths: Path[] = paths;
  constructor(private router: Router, public functions: Functions, public settings: Settings, public account: Account, public project: Project) { }

  ngOnInit() {
    this.onRoute();
    this.getSettings();
    this.router.events.subscribe(() => this.onRoute());
    this.settings.onChange.subscribe(() => this.getSettings());
  }

  onRoute() {
    this.pathname = window.location.pathname;
    this.mode = this.pathname.split('/')[1];
    for (let i in this.paths) {
      let path = this.paths[i]
      if (path.name == this.mode) {
        this.path = path;
        if (path.menu && path.menu.length != 0) {
          let menu = path.menu;
          for (let j in menu) {
            if (menu[j]['path'] == this.pathname) {
              this.settings.setTitle(menu[j]['title']);
              break;
            }
          }
        } else {
          this.settings.setTitle(path['title']);
        }
        break;
      }
    }
  }

  goTo(path = '', mode = '', title = '') {
    if (path == '/project/logout') return this.project.logout();
    else {
      this.router.navigate([path]);
      this.mode = mode;
      this.settings.setTitle(title);
    }
  }

  getSettings() {
    this.mini = this.settings.miniAppBar;
  }

  setMiniAppBar() {
    this.settings.miniAppBar = !this.settings.miniAppBar;
    this.settings.setChanges();
  }
}