import { Component, OnInit } from '@angular/core';
import { Socket } from '../../../services/socket/socket.service';
import { Account } from '../../../services/account/account.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['../auth.component.css', './login.component.css']
})
export class LoginComponent implements OnInit {

  public email: string = '';
  public password: string = '';
  public error = { "email": null, "password": null, "submit": null, "login": null };
  public loading: boolean = false;
  public forget: boolean = true;
  constructor(private socket: Socket, private account: Account, private router: Router) { }

  ngOnInit() {
  }

  validate() {
    let status = true;

    this.error = { "email": null, "password": null, "submit": null, "login": null };
    if (this.email.length == 0) {
      status = false;
      this.error['email'] = "وارد کنید";
    }
    if (this.password.length == 0) {
      status = false;
      this.error['password'] = "وارد کنید";
    }

    if (this.email.length != 0 && /^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$/.test(this.email) == false) {
      status = false;
      this.error['email'] = "غیر قابل قبول";
    }
    if (this.password.length != 0 && this.password.length < 8) {
      status = false;
      this.error['password'] = "کمتر از 8 کارکتر";
    }

    return status;
  }

  submit() {
    if (this.validate()) {
      this.loading = true;
      this.socket.rayconnect.Request({
        scope: 'chat',
        uniqueID: 'chat-admin',
        TokenID: '*',
        address: 'chat/login',
        info: {
          method: 'CHAT',
          data: {
            email: this.email,
            password: this.password
          }
        }
      },
        {
          scope: 'chat',
          address: 'chat/login/status',
          method: 'CHAT'
        }).then(data => {
          data = data['data'];
          if (data['status'] == false && data['message'] == "USERNAME_OR_PASSWORD_IS_INVALID") { return Promise.reject({ message: "آدرس ایمیل یا رمزعبور اشتباه است.", where: "chat/login/status" }) }
          else if (data['status'] == true && data['message'] == "ACCEPT") {
            return this.socket.rayconnect.LoginWithPassword({ username: this.email, password: this.password })
          } else { return Promise.reject({ message: 'خطایی رخ داد' }) }
        }).then(data => {
          if (!data) { return Promise.reject({ message: 'خطایی رخ داد' }) }
          else if (data['status'] == true) {
            if (this.forget == true) {
              window.sessionStorage.setItem('token', data['data']['token']);
            } else {
              window.localStorage.setItem('token', data['data']['token']);
            }
            return this.socket.rayconnect.Auth(data['data']['token']);
          } else {
            return Promise.reject({ message: "آدرس ایمیل یا رمزعبور اشتباه است.", where: "LoginWithPassword" })
          }
        })
        .then(() => {
          return this.socket.rayconnect.Request({
            scope: 'chat',
            uniqueID: 'chat-admin',
            TokenID: '*',
            address: 'chat/me',
            info: { method: 'CHAT', data: {} }
          },
            {
              scope: 'chat',
              address: 'chat/me/data',
              method: 'CHAT'
            })
        })
        .then(data => {
          this.loading = false;
          data = data['data'];
          this.account.fullname = data['fullname'];
          this.account.email = data['email'];
          this.router.navigate(['/panel/dashboard']);
          this.account.set();
        })
        .catch((error) => {
          console.log("[RayConnect Error]: ", error);
          this.loading = false;
          this.error.submit = (error == 'request timeout : 3000') ? 'عدم اتصال به سرور' : error['message'] || 'خطایی رخ داده است';
        });
    }
  }

  loginWithGoogle() {
    this.error = { "email": null, "password": null, "submit": null, "login": null };

    this.error.login = "غیر فعال";
  }
}
