import { Component, OnInit } from '@angular/core';
import { Socket } from '../../../services/socket/socket.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-register',
  templateUrl: './register.component.html',
  styleUrls: ['../auth.component.css', './register.component.css']
})
export class RegisterComponent implements OnInit {

  public loading: boolean = false;
  public fullname: string = '';
  public email: string = '';
  public password: string = '';
  public trypassword: string = '';
  public confirm: boolean = false;
  public error = { fullname: null, email: null, password: null, trypassword: null, confirm: false, submit: null };
  constructor(private socket: Socket, private router: Router) { }

  ngOnInit() {
  }

  validate() {
    let status = true;

    this.error = { fullname: null, email: null, password: null, trypassword: null, confirm: false, submit: null };
    if (this.fullname.length == 0) {
      status = false;
      this.error['fullname'] = "وارد کنید";
    }
    if (this.email.length == 0) {
      status = false;
      this.error['email'] = "وارد کنید";
    }
    if (this.password.length == 0) {
      status = false;
      this.error['password'] = "وارد کنید";
    }
    if (this.trypassword.length == 0) {
      status = false;
      this.error['trypassword'] = "وارد کنید";
    }

    if (this.email.length != 0 && /^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$/.test(this.email) == false) {
      status = false;
      this.error['email'] = "غیر قابل قبول";
    }
    if (this.password.length != 0 && this.password.length < 8) {
      status = false;
      this.error['password'] = "کمتر از 8 کارکتر";
    }
    if (this.trypassword.length != 0 && this.trypassword.length < 8) {
      status = false;
      this.error['trypassword'] = "کمتر از 8 کارکتر";
    }
    if (this.trypassword != this.password) {
      status = false;
      this.error['trypassword'] = "یکی نیست";
    }

    if (this.confirm == false) {
      status = false;
      this.error['confirm'] = true;
    }

    return status;
  }

  submit() {
    if (this.validate()) {
      this.loading = true;
      this.socket.rayconnect.Request({
        scope: 'chat',
        uniqueID: 'chat-admin',
        TokenID: '*',
        address: 'chat/register',
        info: {
          method: 'CHAT',
          data: {
            fullname: this.fullname,
            email: this.email,
            password: this.password
          }
        }
      },
        {
          scope: 'chat',
          address: 'chat/register/status',
          method: 'CHAT'
        }).then(data => {
          this.loading = false;
          data = data['data'];
          if (data['status'] == false && data['message'] == "REGISTER_IS_NOT_AVAILABLE") return Promise.reject({ message: 'اکنون نمی توانید ثبت نام کنید.' });
          else if (data['status'] == false && data['message'] == "EMAIL_IS_DUP") return Promise.reject({ message: 'ثبت شده است', on: 'email' });
          else if (data['status'] == true) this.router.navigate(['/auth/login']);
          else return Promise.reject({ message: 'خطایی رخ داد' });
        })
        .catch((error) => {
          console.log("[RayConnect Error]: ", error);
          this.loading = false;
          this.error[error['on'] || 'submit'] = (error == 'request timeout : 3000') ? 'عدم اتصال به سرور' : error['message'] || 'خطایی رخ داده است';
        });
    }
  }
}
