import { Component, OnInit } from '@angular/core';
import { Settings } from '../../../../services/settings/settings.service';
import { Account } from '../../../../services/account/account.service';
import { Socket } from '../../../../services/socket/socket.service';

@Component({
  selector: 'app-profile',
  templateUrl: './profile.component.html',
  styleUrls: ['./profile.component.css']
})
export class ProfileComponent implements OnInit {

  public fullname: string = '';
  public phone: string = '';
  public avatar: string = '0';
  public showSelectAvatar: boolean = false;
  public loading: boolean = false;
  constructor(public settings: Settings, public account: Account, private socket: Socket) { }

  ngOnInit() {
    this.fullname = this.account.fullname;
    this.phone = this.account.phone;
    this.avatar = this.account.avatar;
  }

  onAvatarSelect(index: string = '0') {
    this.avatar = index;
    this.showSelectAvatar = false;
  }

  submit() {
    this.loading = true;
    this.socket.rayconnect.Request({
      scope: 'chat',
      uniqueID: 'chat-admin',
      TokenID: '*',
      address: 'chat/me/edit',
      info: {
        method: 'CHAT',
        data: {
          fullname: this.fullname,
          phone: this.phone,
          avatar: this.avatar
        }
      }
    },
      {
        scope: 'chat',
        address: 'chat/me/edit/status',
        method: 'CHAT'
      }).then(data => {
        this.loading = false;
        if (data['data']['status'] == true) {
          this.account.fullname = this.fullname;
          this.account.phone = this.phone;
          this.account.avatar = this.avatar;
          this.settings.setChanges('saved');
        }
      })
  }
}
