import { Component, OnInit } from '@angular/core';
import { Settings } from '../../../services/settings/settings.service';
import { Account } from '../../../services/account/account.service';
import { ActivatedRoute } from '@angular/router';
import cities, { City } from '../../../database/cities.database';

@Component({
  selector: 'app-app',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent implements OnInit {

  public mini: boolean = false;
  public cities: City[] = cities;
  constructor(public settings: Settings, public account: Account, private activatedRoute: ActivatedRoute) { }

  ngOnInit() {
    this.getSettings();
    this.settings.onChange.subscribe(() => this.getSettings());
    this.activatedRoute.params.subscribe(params => {
      if (document.getElementById(params['id']))
        document.getElementById(params['id']).scrollIntoView();
    })
  }

  getSettings() {
    this.mini = this.settings.miniAppBar;
  }

  setColorByIndex(index: number = 0) {
    this.settings.setColor(this.settings.colors[index]['name'], this.settings.colors[index]['background'], this.settings.colors[index]['text'], this.settings.colors[index]['night']);
    this.settings.setChanges('color');
  }

  pickColor() {
    let id = 'rayconnect-color-picker'
    if (document.getElementById(id)) document.body.removeChild(document.getElementById(id));
    let input = document.createElement('input');
    input.type = 'color';
    input.style.display = 'none';
    input.id = id;
    document.body.appendChild(input);
    input.click();
    input.onchange = () => {
      this.settings.setColor('custom', input.value, '#fff');
      this.settings.setChanges('color');
      document.body.removeChild(input);
    }
  }

  toggle(what: string) {
    if (what == 'showUserInfo' && this.mini == true) return false;
    if (what == 'nightMode' && this.settings.nightMode == false && this.settings.color.night == false) this.setColorByIndex(0);
    this.settings[what] = !this.settings[what];
    this.settings.setChanges(what);
    this.settings.saveChanges();
  }

  set(what: string, value: any) {
    this.settings[what] = value;
    this.settings.setChanges(what);
    this.settings.saveChanges();
  }

  doResetSettings() {
    this.settings.setDefault(true);
    this.setColorByIndex(0);
  }
}
