import { Injectable } from '@angular/core';
import database from './project.database';
import { BehaviorSubject } from 'rxjs';

@Injectable({
  providedIn: 'root'
})
export class Project {

  public id: string = null;
  public name: string = '';
  public icon: number = -1;
  public color: number = 1;
  public category: string = '';
  public domain: string[] = [];
  public descriptions: string = '';
  public module: string[] = [];
  public owner = null;
  public database = database;
  public onSelect = new BehaviorSubject<boolean>(false);
  constructor() { }

  set(data = { _id: '', name: '', icon: -1, color: 1, domain: [], descriptions: '', module: [], owner: null }, forget: boolean = false) {
    this.id = data._id;
    this.name = data.name;
    this.icon = data.icon;
    this.category = this.database.icons[data.icon]['name'];
    this.color = data.color;
    this.domain = data.domain;
    this.descriptions = data.descriptions;
    this.module = data.module;
    this.owner = data.owner;
    this.onSelect.next(true);
    if (forget == true) window.localStorage.setItem('project', data._id);
    else window.sessionStorage.setItem('project', data._id);
  }

  logout() {
    this.id = null;
    this.name = '';
    this.icon = -1;
    this.color = 1;
    this.category = '';
    this.domain = [];
    this.descriptions = '';
    this.module = [];
    this.owner = null;
    window.sessionStorage.removeItem('project');
    window.localStorage.removeItem('project');
    this.onSelect.next(false);
  }
}
