import { Injectable } from '@angular/core';
import { BehaviorSubject } from 'rxjs';

interface Color {
  name: string,
  background: string,
  text: string,
  night: boolean
}

declare global {
  interface Window {
    RayConnect: any;
  }
}

@Injectable({
  providedIn: 'root'
})
export class Settings {

  public onChange = new BehaviorSubject<string>(null);
  public showNetworkStatus: boolean = true;
  public miniAppBar: boolean = false;
  public hideAppBar: boolean = false;
  public topAppBar: boolean = false;
  public showUserInfo: boolean = true;
  public showAddAmountWallet: boolean = false;
  public forgetProject: boolean = false;
  public appInstallAble: boolean = false;
  public nightMode: boolean = false;
  public colors: Color[] = [
    { name: 'blue', background: '#2b50ed', text: '#fff', night: true },
    { name: 'yellow', background: '#fac72d', text: '#fff', night: true },
    { name: 'green', background: '#2cca74', text: '#fff', night: true },
    { name: 'red', background: '#ff2a2a', text: '#fff', night: true },
    { name: 'pink', background: '#FF1493', text: '#fff', night: true },
    { name: 'brown', background: '#400040', text: '#fff', night: false }
  ];
  public color: Color;
  public cityId: string = null;
  public weatherDayCount: number = 7;
  constructor() { }

  async load() {
    let settings: any = await window.localStorage.getItem('settings');
    if (settings == null) this.setDefault();
    else {
      try {
        settings = await JSON.parse(settings);
        this.showNetworkStatus = settings['showNetworkStatus'] || true;
        this.nightMode = settings['nightMode'] || false;
        this.miniAppBar = settings['miniAppBar'] || false;
        this.topAppBar = settings['topAppBar'] || false;
        this.showUserInfo = settings['showUserInfo'] || true;
        this.forgetProject = settings['forgetProject'] || false;
        this.cityId = settings['cityId'] || null;
        this.weatherDayCount = settings['weatherDayCount'] || 7;
      } catch (error) {
        this.setDefault();
      }
    }
    let color: any = await window.localStorage.getItem('color');
    if (color == null) this.color = this.colors[0];
    else {
      try {
        color = await JSON.parse(color);
        this.color = { name: color['name'] || this.colors[0]['name'], background: color['background'] || this.colors[0]['background'], text: color['text'] || this.colors[0]['text'], night: color['night'] };
        this.changeColor();
      } catch (error) {
        this.color = this.colors[0];
      }
    }
  }

  setColor(name: string = 'custom', background: string = '', text: string = '', night: boolean = true) {
    this.color = { name, background, text, night };
    this.changeColor();
    window.localStorage.setItem('color', JSON.stringify(this.color));
  }

  private changeColor() {
    document.documentElement.style.setProperty('--background', this.color.background);
    document.documentElement.style.setProperty('--text', this.color.text);
  }

  saveChanges() {
    window.localStorage.setItem('settings', JSON.stringify({ showNetworkStatus: this.showNetworkStatus, nightMode: this.nightMode, miniAppBar: this.miniAppBar, showUserInfo: this.showUserInfo, topAppBar: this.topAppBar, forgetProject: this.forgetProject, cityId: this.cityId, weatherDayCount: this.weatherDayCount }));
  }

  setChanges(title = "") {
    this.onChange.next(title);
  }

  setDefault(remove: boolean = false) {
    this.showNetworkStatus = true;
    this.nightMode = false;
    this.miniAppBar = false;
    this.topAppBar = false;
    this.showUserInfo = true;
    this.forgetProject = true;
    this.cityId = null;
    this.weatherDayCount = 7;
    if (remove == true) this.saveChanges();
  }

  setTitle(title = '') {
    document.title = 'رایکانکت | ' + title;
  }
}
