import { Injectable, EventEmitter, PLATFORM_ID, Inject } from '@angular/core';
import Rayconnect from 'rayconnect-client';
import * as pathToRegexp from 'path-to-regexp';
import { isPlatformBrowser, isPlatformServer } from '@angular/common';

@Injectable({
  providedIn: 'root'
})

export class Socket {

  public rayconnect: Rayconnect
  queryChange: EventEmitter<any> = new EventEmitter();
  LoginChange: EventEmitter<any> = new EventEmitter();
  AuthChange: EventEmitter<any> = new EventEmitter();
  TimeOut

  private EmitterInterval
  longProcessOutput: string;
  guest: boolean;


  constructor(@Inject(PLATFORM_ID) private platform: Object) {


    if (isPlatformBrowser(this.platform)) {



      this.rayconnect = new Rayconnect({
        scopes: "chat,project,admin",
        appID: 'rayGap',
        space: 'chat',
        type: 'client'
      }, undefined, true);

      this.rayconnect.DisOnConnect(() => {
        this.TimeOut = setTimeout(() => {
          window.location.reload()
        }, 20000);
      })
      this.rayconnect.OnConnect(() => {

        clearTimeout(this.TimeOut);

      });

      this.TimeOut = setTimeout(() => {
        window.location.reload()
      }, 20000);

      this.rayconnect.socket.on('exec_gram', async (msg) => {




        const data = this.rayconnect.Dpack(msg);





        // send ack
        this.rayconnect.Ack(data.info.reqID);






        this.queryChange.emit(data);
        // callback(, query)



      });

      this.rayconnect.socket.on('login', (msg) => {
        const data = this.rayconnect.Dpack(msg);

         this.EmitterInterval =setInterval(() => {
          this.LoginChange.emit(data);
        }, 200);

      });

      this.rayconnect.AuthEvent.on('authed', (msg) => {
        this.AuthChange.emit(msg);
      });


    }
  }

  getConnection() {
    return this.rayconnect;
  }
  GetGuestAccess(){
    this.guest = true;
    return this.rayconnect.GetGuestAccess();
  }
  Mute(){

    clearInterval(this.EmitterInterval)
  }
  Query(query, data, callback) {




    if ((data.scope === query.scope) && (data
      .info
      .method === query.method)) {

      const opts = {
        strict: false,
        sensitive: false,
        end: true
      };
      const keys = [];
      const regexp = pathToRegexp(query.address, keys, opts);


      const result = regexp.exec(data.address);

      const params = {};

      keys.map((key, i) => {
        if (!result) { return }

        if (result[i + 1]) {
          const m = typeof result[i + 1];
          if (m == 'string') {
            params[key.name] = result[i + 1];
          }

        }
      });

      if (result) {
        return callback({
          sender: data.uid,
          token: data.token,
          data: JSON.parse(data.info.data),
          params: params,
          date: data.info.date
        });
      }




    }
  }
  AuthChecker() {
    const queryChange: EventEmitter<any> = new EventEmitter();

    if (localStorage.getItem('offlineMode')) {

      setTimeout(() => {
        queryChange.emit(true);

      }, 1);

      return queryChange;
    }
    this.rayconnect.onAuth('checker', (authed) => {
      queryChange.emit(authed);

    });

    return queryChange;

  }
}
